@@ -15,8 +15,6 @@
 # under the License.
 import random
 import socket
-import threading
-import time
 
 import dns.exception
 import dns.message
@@ -41,7 +39,7 @@ class TsigKeyring(dict):
     """Implements the DNSPython KeyRing API, backed by the Designate DB"""
 
     def __init__(self, storage):
-        super(TsigKeyring, self).__init__()
+        super().__init__()
         self.storage = storage
 
     def __getitem__(self, key):
@@ -50,8 +48,6 @@ class TsigKeyring(dict):
     def get(self, key, default=None):
         try:
             name = key.to_text(True)
-            if isinstance(name, bytes):
-                name = name.decode('utf-8')
             criterion = {'name': name}
             tsigkey = self.storage.find_tsigkey(
                 context.get_current(), criterion
@@ -63,53 +59,6 @@ class TsigKeyring(dict):
             return default
 
 
-class ZoneLock(object):
-    """A Lock across all zones that enforces a rate limit on NOTIFYs"""
-
-    def __init__(self, delay):
-        self.lock = threading.Lock()
-        self.data = {}
-        self.delay = delay
-
-    def acquire(self, zone):
-        with self.lock:
-            # If no one holds the lock for the zone, grant it
-            if zone not in self.data:
-                self.data[zone] = time.monotonic()
-                return True
-
-            # Otherwise, get the time that it was locked
-            locktime = self.data[zone]
-            now = time.monotonic()
-
-            period = now - locktime
-
-            # If it has been locked for longer than the allowed period
-            # give the lock to the new requester
-            if period > self.delay:
-                self.data[zone] = now
-                return True
-
-            LOG.debug(
-                'Lock for %(zone)s can\'t be released for %(period)s seconds',
-                {
-                    'zone': zone,
-                    'period': str(self.delay - period)
-                }
-            )
-
-            # Don't grant the lock for the zone
-            return False
-
-    def release(self, zone):
-        # Release the lock
-        with self.lock:
-            try:
-                self.data.pop(zone)
-            except KeyError:
-                pass
-
-
 def from_dnspython_zone(dnspython_zone):
     # dnspython never builds a zone with more than one SOA, even if we give
     # it a zonefile that contains more than one
@@ -119,14 +68,9 @@ def from_dnspython_zone(dnspython_zone):
     if soa.ttl == 0:
         soa.ttl = CONF['service:central'].min_ttl
     email = soa[0].rname.to_text(omit_final_dot=True)
-    if isinstance(email, bytes):
-        email = email.decode('utf-8')
     email = email.replace('.', '@', 1)
 
     name = dnspython_zone.origin.to_text()
-    if isinstance(name, bytes):
-        name = name.decode('utf-8')
-
     values = {
         'name': name,
         'email': email,
@@ -145,15 +89,9 @@ def from_dnspython_zone(dnspython_zone):
 
 def dnspyrecords_to_recordsetlist(dnspython_records):
     rrsets = objects.RecordSetList()
-
     for rname in dnspython_records.keys():
         for rdataset in dnspython_records[rname]:
-            rrset = dnspythonrecord_to_recordset(rname, rdataset)
-
-            if rrset is None:
-                continue
-
-            rrsets.append(rrset)
+            rrsets.append(dnspythonrecord_to_recordset(rname, rdataset))
     return rrsets
 
 
@@ -161,8 +99,6 @@ def dnspythonrecord_to_recordset(rname, rdataset):
     record_type = dns.rdatatype.to_text(rdataset.rdtype)
 
     name = rname.to_text()
-    if isinstance(name, bytes):
-        name = name.decode('utf-8')
 
     # Create the other recordsets
 
@@ -170,6 +106,7 @@ def dnspythonrecord_to_recordset(rname, rdataset):
         'name': name,
         'type': record_type
     }
+
     if rdataset.ttl != 0:
         values['ttl'] = rdataset.ttl
 
@@ -183,10 +120,7 @@ def dnspythonrecord_to_recordset(rname, rdataset):
 
 
 def xfr_timeout():
-    if CONF['service:mdns'].xfr_timeout is not None:
-        return CONF['service:mdns'].xfr_timeout
-    else:
-        return CONF['service:worker'].xfr_timeout
+    return CONF['service:worker'].xfr_timeout
 
 
 def do_axfr(zone_name, servers, source=None):
@@ -212,28 +146,28 @@ def do_axfr(zone_name, servers, source=None):
                     port=srv['port'], source=source
                 )
                 raw_zone = dns.zone.from_xfr(xfr, relativize=False)
-                LOG.debug("AXFR Successful for %s", raw_zone.origin.to_text())
+                LOG.debug('AXFR Successful for %s', raw_zone.origin.to_text())
                 return raw_zone
             except eventlet.Timeout as t:
                 if t == to:
-                    LOG.error("AXFR timed out for %(name)s from %(host)s",
+                    LOG.error('AXFR timed out for %(name)s from %(host)s',
                               log_info)
                     continue
             except dns.exception.FormError:
-                LOG.error("Zone %(name)s is not present on %(host)s."
-                          "Trying next server.", log_info)
-            except socket.error:
-                LOG.error("Connection error when doing AXFR for %(name)s from "
-                          "%(host)s", log_info)
+                LOG.error('Zone %(name)s is not present on %(host)s.'
+                          'Trying next server.', log_info)
+            except OSError:
+                LOG.error('Connection error when doing AXFR for %(name)s from '
+                          '%(host)s', log_info)
             except Exception:
-                LOG.exception("Problem doing AXFR %(name)s from %(host)s. "
-                              "Trying next server.", log_info)
+                LOG.exception('Problem doing AXFR %(name)s from %(host)s. '
+                              'Trying next server.', log_info)
             finally:
                 to.cancel()
 
     raise exceptions.XFRFailure(
-        "XFR failed for %(name)s. No servers in %(servers)s was reached." %
-        {"name": zone_name, "servers": servers}
+        'XFR failed for %(name)s. No servers in %(servers)s was reached.' %
+        {'name': zone_name, 'servers': servers}
     )
 
 
@@ -267,10 +201,7 @@ def soa_query(zone_name, host, port=53, timeout=10):
 
 
 def use_all_tcp():
-    if CONF['service:mdns'].all_tcp is not None:
-        return CONF['service:mdns'].all_tcp
-    else:
-        return CONF['service:worker'].all_tcp
+    return CONF['service:worker'].all_tcp
 
 
 def send_dns_message(dns_message, host, port=53, timeout=10):
